package com.fs.hospital.service;

import java.util.List;
import com.fs.hospital.domain.HospitalExamItem;

/**
 * 检验项目Service接口
 * 
 * @author fs
 * @date 2024-03-26
 */
public interface IHospitalExamItemService 
{
    /**
     * 查询检验项目
     * 
     * @param examId 检验项目主键
     * @return 检验项目
     */
    public HospitalExamItem selectHospitalExamItemByExamId(Long examId);

    /**
     * 查询检验项目列表
     * 
     * @param hospitalExamItem 检验项目
     * @return 检验项目集合
     */
    public List<HospitalExamItem> selectHospitalExamItemList(HospitalExamItem hospitalExamItem);

    /**
     * 新增检验项目
     * 
     * @param hospitalExamItem 检验项目
     * @return 结果
     */
    public int insertHospitalExamItem(HospitalExamItem hospitalExamItem);

    /**
     * 修改检验项目
     * 
     * @param hospitalExamItem 检验项目
     * @return 结果
     */
    public int updateHospitalExamItem(HospitalExamItem hospitalExamItem);

    /**
     * 批量删除检验项目
     * 
     * @param examIds 需要删除的检验项目主键集合
     * @return 结果
     */
    public int deleteHospitalExamItemByExamIds(Long[] examIds);

    /**
     * 删除检验项目信息
     * 
     * @param examId 检验项目主键
     * @return 结果
     */
    public int deleteHospitalExamItemByExamId(Long examId);
}
